@@ -104,10 +104,10 @@ except ImportError:
                 " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.2.7'
+__version__ = '2.2.8'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
-                     r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
+                     r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
 SPECREX = re.compile(r'^\s*@(\w+)\s([^#\n]*)(\s+#\s*([^\n]*)|$)')
 DEVNULL = ">/dev/null 2>&1"
 
@@ -141,6 +141,9 @@ PY3 = platform.python_version()[0] == '3'
 WINOS = platform.system() == 'Windows'
 SYSTEMV = not WINOS and os.uname()[0] in ["SunOS", "AIX", "HP-UX"]
 
+# Switch this on if you want your crontabs to have zero padding.
+ZERO_PAD = False
+
 LOG = logging.getLogger('crontab')
 
 CRONCMD = "/usr/bin/crontab"
@@ -383,6 +386,8 @@ class CronTab(object):
                     line.enabled = False
                 crons.append(unicode(line))
 
+        # Environment variables are attached to cron lines so order will
+        # always work no matter how you add lines in the middle of the stack.
         result = unicode(self.env) + u'\n'.join(crons)
         if result and result[-1] not in (u'\n', u'\r'):
             result += u'\n'
@@ -570,6 +575,7 @@ class CronItem(object):
         if not line or line[0] == '#':
             self.enabled = False
             line = line[1:].strip()
+        # We parse all lines so we can detect disabled entries.
         self._set_parse(ITEMREX.findall(line))
         self._set_parse(SPECREX.findall(line))
 
@@ -1175,7 +1181,7 @@ def _render(value, resolve=False):
         return value.render(resolve)
     if resolve:
         return str(int(value))
-    return unicode(value)
+    return unicode(u'{:02d}'.format(value) if ZERO_PAD else value)
 
 
 class CronRange(object):
